import { Button } from "@/components/ui/button"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Twitter, MessageCircle, Youtube, BookOpen, ArrowRight } from "lucide-react"
import { ConnectWalletButton } from "./components/connect-wallet"
import { orbitron } from "./fonts"

export default function LandingPage() {
  return (
    <div className={`min-h-screen bg-gradient-to-b from-blue-100 to-blue-200 text-gray-800 ${orbitron.className}`}>
      <header className="container mx-auto p-4 flex flex-col items-center justify-center">
        <h1 className="text-5xl font-bold mb-4 text-center">The One Token</h1>
        <ConnectWalletButton />
      </header>

      <main>
        <HeroSection />
        <FeaturesSection />
        <RoadmapSection />
        <TokenomicsSection />
        <AdvantagesSection />
        <CommunitySection />
      </main>

      <footer className="container mx-auto p-4 text-center">
        <p>&copy; 2025 The One Token. All rights reserved.</p>
      </footer>
    </div>
  )
}

function HeroSection() {
  return (
    <section className="container mx-auto px-4 py-20 text-center">
      <h2 className="text-6xl font-bold mb-6 tracking-wider">The Future of Cryptocurrency</h2>
      <p className="text-xl mb-8 max-w-2xl mx-auto">
        Our revolutionary crypto project, The One Token, is leading the transition from Web3 to Web4. With cutting-edge
        technology and a dynamic vision, we are shaping the future of decentralized finance.
      </p>
      <Button size="lg" className="bg-blue-500 text-white hover:bg-blue-600">
        Buy The One Token Now <ArrowRight className="ml-2" />
      </Button>
    </section>
  )
}

function FeaturesSection() {
  const features = [
    {
      title: "What is The One Token?",
      items: [
        "Token Details: The One Token is a revolutionary cryptocurrency designed to power the future of finance.",
        "Ecosystem Integration: Seamlessly integrates into existing and emerging financial systems.",
        "Token Purpose: Acts as a bridge between traditional finance and the decentralized world.",
      ],
    },
    {
      title: "The One Token Ecosystem",
      items: [
        "Web3 Applications: Provides the foundation for innovative Web3 to Web4 applications.",
        "Digitisation of Real World Assets: Features digitisation of assets that generate real-world profits.",
        "Multi Chain Support: Supported on multiple chains to accommodate low fees.",
      ],
    },
  ]

  return (
    <section className="container mx-auto px-4 py-20">
      <h2 className="text-5xl font-bold mb-10 text-center tracking-wide">Features</h2>
      <div className="grid md:grid-cols-2 gap-8">
        {features.map((feature, index) => (
          <Card key={index} className="bg-white border-gray-200 shadow-md">
            <CardHeader>
              <CardTitle className="text-2xl tracking-wide">{feature.title}</CardTitle>
            </CardHeader>
            <CardContent>
              <ul className="list-disc pl-5 space-y-2">
                {feature.items.map((item, itemIndex) => (
                  <li key={itemIndex}>{item}</li>
                ))}
              </ul>
            </CardContent>
          </Card>
        ))}
      </div>
    </section>
  )
}

function RoadmapSection() {
  const phases = [
    {
      title: "Phase 1: Development",
      description:
        "Focuses on building the core infrastructure and functionalities of The One Token. This is already done.",
    },
    {
      title: "Phase 2: Launch and Expansion",
      description:
        "The One Token is launched and integrated into the wider crypto ecosystem first on Smart Chain and soon to other L2's.",
    },
    {
      title: "Phase 3: Ecosystem Growth",
      description:
        "We will start to roll out (RWA) Real World Assets and applications Focused on building a new ecosystem of applications and services powered by The One Token.",
    },
  ]

  return (
    <section className="container mx-auto px-4 py-20">
      <h2 className="text-5xl font-bold mb-10 text-center tracking-wide">The One Token Roadmap</h2>
      <div className="space-y-8">
        {phases.map((phase, index) => (
          <Card key={index} className="bg-white border-gray-200 shadow-md">
            <CardHeader>
              <CardTitle className="text-2xl tracking-wide">{phase.title}</CardTitle>
            </CardHeader>
            <CardContent>
              <p>{phase.description}</p>
            </CardContent>
          </Card>
        ))}
      </div>
    </section>
  )
}

function TokenomicsSection() {
  const tokenomics = [
    {
      title: "Soaring Token Scarcity",
      description:
        "The revolutionary One Token features a dynamic burn mechanism that systematically reduces the total supply over time.",
    },
    {
      title: "Unleash the Power of Our Token",
      description:
        "Jump into our thriving community and unlock a world of rewarding incentives through our innovative token distribution model.",
    },
    {
      title: "Endless Possibilities with The One Token",
      description:
        "From powering transactions to unlocking exclusive rewards, the limitless use cases of the One Token make it the ultimate cryptocurrency for your digital life.",
    },
  ]

  return (
    <section className="container mx-auto px-4 py-20">
      <h2 className="text-5xl font-bold mb-10 text-center tracking-wide">The One Token Tokenomics</h2>
      <div className="grid md:grid-cols-3 gap-8">
        {tokenomics.map((item, index) => (
          <Card key={index} className="bg-white border-gray-200 shadow-md">
            <CardHeader>
              <CardTitle className="text-2xl tracking-wide">{item.title}</CardTitle>
            </CardHeader>
            <CardContent>
              <p>{item.description}</p>
            </CardContent>
          </Card>
        ))}
      </div>
    </section>
  )
}

function AdvantagesSection() {
  const advantages = [
    {
      title: "More ways to earn",
      description:
        "The One Token utilises advanced Tokenomics features to ensure the most advantageous to its holders. Tax system that is paid to all holders in stable coins.",
    },
    {
      title: "There is no team allocation of tokens",
      description:
        "The One Token operates on a commission based tax system so we have to keep working for you to get paid. This is a next first in the crypto space.",
    },
    {
      title: "Dividend distribution System",
      description:
        "The One Token is designed to distribute dividend from Real World Assets to holders according to the percentage of tokens held by all users in Stable Coins.",
    },
  ]

  return (
    <section className="container mx-auto px-4 py-20">
      <h2 className="text-5xl font-bold mb-10 text-center tracking-wide">The One Token Advantages</h2>
      <div className="space-y-8">
        {advantages.map((advantage, index) => (
          <Card key={index} className="bg-white border-gray-200 shadow-md">
            <CardHeader>
              <CardTitle className="text-2xl tracking-wide">{advantage.title}</CardTitle>
            </CardHeader>
            <CardContent>
              <p>{advantage.description}</p>
            </CardContent>
          </Card>
        ))}
      </div>
    </section>
  )
}

function CommunitySection() {
  const communities = [
    {
      name: "Twitter",
      icon: Twitter,
      description: "Follow us on Twitter for the latest updates, news, and community engagement.",
      url: "https://x.com/TheOneToken_",
    },
    {
      name: "Telegram",
      icon: MessageCircle,
      description: "Join our Telegram group for real-time discussions and community support.",
      url: "https://t.me/TheOneTokenWeb4",
    },
    {
      name: "YouTube",
      icon: Youtube,
      description: "Connect with other enthusiasts on our YouTube channel for community events and discussions.",
      url: "https://www.youtube.com/channel/UCPslQID_9oGDc1oVREbMZGA",
    },
    {
      name: "TikTok",
      icon: BookOpen,
      description: "Follow us on TikTok for the latest video updates and content.",
      url: "https://www.tiktok.com/@theonetoken?_t=8sdCp3M899p&_r=1",
    },
  ]

  return (
    <section className="container mx-auto px-4 py-20">
      <h2 className="text-5xl font-bold mb-10 text-center tracking-wide">Join The One Token Community</h2>
      <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
        {communities.map((community, index) => (
          <a
            key={index}
            href={community.url}
            target="_blank"
            rel="noopener noreferrer"
            className="block transition-transform hover:scale-105"
          >
            <Card className="bg-white border-gray-200 shadow-md">
              <CardHeader>
                <CardTitle className="flex items-center text-2xl tracking-wide">
                  <community.icon className="mr-2" />
                  {community.name}
                </CardTitle>
              </CardHeader>
              <CardContent>
                <p>{community.description}</p>
              </CardContent>
            </Card>
          </a>
        ))}
      </div>
    </section>
  )
}

